<?php

namespace FM\Factory;

use Doctrine\ORM\EntityManager;
use FM\Traits\TQuery;

class Fm00002VistoriasFactory
{

    use TQuery;
    protected $entityManager;
    protected $connection;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager    = $entityManager;
    }

    public function getVistoriasListadas($listaOperadoes, $filtros)
    {
        $sql = "SELECT NRGERENCIAMENTOCHK, NMGERENCIAMENTOCHK, NRLOCALCLIENTE, CDOPERADOR, 
                            IDSITUACAOGERCHK, NRSEQCONTRATO, NRCONTRATOFCT, NMFANTCLIE,
                            DTAGEND, HORAAGEND, NMOPERADOR, NMLOCALCLIENTE, LOCALPAI, NMLOCALPAI, 
                            IDSITUACAOAGEND, SUPERVISOR, NMCHECKLISTAGEND, OBS, DATACOMPLETA, SITUACAO
                    FROM (SELECT GCHK.NRGERENCIAMENTOCHK, GCHK.NMGERENCIAMENTOCHK, GCHK.NRLOCALCLIENTE, GCHK.CDOPERADOR, 
                            GCHK.IDSITUACAOGERCHK, GCHK.NRSEQCONTRATO, CT.NRCONTRATOFCT, C.NMFANTCLIE,
                            TO_CHAR(GCHK.DTHORAAGEND, 'DD/MM') DTAGEND,  TO_CHAR(GCHK.DTHORAAGEND, 'HH24:MI') HORAAGEND,
                            FUNC.NMOPERADOR, LC.NMLOCALCLIENTE, LC.NRLOCALCLIENTEPAI AS LOCALPAI, LCP.NMLOCALCLIENTE AS NMLOCALPAI, 
                            CA.IDSITUACAOAGEND, FUNCOP.NMOPERADOR AS SUPERVISOR, CA.NMCHECKLISTAGEND, MAX(FCM_TAREFAGERCHK.DSOBSTAREFAGERCHK) AS OBS, GCHK.DTHORAAGEND AS DATACOMPLETA,
                            CASE GCHK.IDSITUACAOGERCHK 
                                    WHEN '1' THEN 'Aguardando Vistoria'
                                    WHEN '2' THEN 'Em andamento'
                                    WHEN '3' THEN 'Avaliado'
                            ELSE NULL END AS SITUACAO
                    FROM FCM_GERENCIAMENTOCHK GCHK
                    INNER JOIN FCM_LOCALCLI LC 
                        ON LC.NRLOCALCLIENTE = GCHK.NRLOCALCLIENTE
                    INNER JOIN OPERADOR FUNC 
                        ON FUNC.CDOPERADOR = GCHK.CDOPERADOR
                    INNER JOIN FCM_LOCALCLI LCP 
                        ON LCP.NRLOCALCLIENTE = LC.NRLOCALCLIENTEPAI
                    INNER JOIN FCM_CHECKLISTAGEND CA 
                        ON CA.NRCHECKLISTAGEND = GCHK.NRCHECKLISTAGEND
                    LEFT JOIN FCT_CONTRATO CT
                        ON CT.NRSEQCONTRATO = GCHK.NRSEQCONTRATO
                    LEFT JOIN CLIENTE C
                        ON C.CDCLIENTE = LC.CDCLIENTE
                    INNER JOIN OPERADOR FUNCOP
                        ON FUNCOP.CDOPERADOR = CA.CDOPERADOR
                    INNER JOIN FCM_TAREFAGERCHK
                        ON FCM_TAREFAGERCHK.NRGERENCIAMENTOCHK = GCHK.NRGERENCIAMENTOCHK
                    WHERE GCHK.CDOPERADOR 
                        IN ({$listaOperadoes})" . $filtros . "
                        AND CA.IDSITUACAOAGEND = '4'
                    GROUP BY GCHK.NRGERENCIAMENTOCHK, GCHK.NMGERENCIAMENTOCHK, GCHK.NRLOCALCLIENTE, GCHK.CDOPERADOR, 
                            GCHK.IDSITUACAOGERCHK, GCHK.NRSEQCONTRATO, CT.NRCONTRATOFCT, C.NMFANTCLIE,
                            TO_CHAR(GCHK.DTHORAAGEND, 'DD/MM'),  TO_CHAR(GCHK.DTHORAAGEND, 'HH24:MI'),
                            FUNC.NMOPERADOR, LC.NMLOCALCLIENTE, LC.NRLOCALCLIENTEPAI, LCP.NMLOCALCLIENTE, 
                            CA.IDSITUACAOAGEND, FUNCOP.NMOPERADOR, CA.NMCHECKLISTAGEND, GCHK.DTHORAAGEND) VISTORIAS
                    ORDER BY DATACOMPLETA";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getFotosVistorias($parametros)
    {

        $sql = "SELECT FCM_FOTOTAREFAGERCHK.NRFOTOTAREFAGERCHK, FCM_FOTOTAREFAGERCHK.DSFOTOTAREFAGERCHK, FCM_GERENCIAMENTOCHK.NRGERENCIAMENTOCHK, FCM_GERENCIAMENTOCHK.NMGERENCIAMENTOCHK
                    FROM FCM_FOTOTAREFAGERCHK
                    JOIN FCM_TAREFAGERCHK 
                    ON FCM_TAREFAGERCHK.NRTAREFAGERCHK = FCM_FOTOTAREFAGERCHK.NRTAREFAGERCHK
                    JOIN FCM_GERENCIAMENTOCHK 
                    ON FCM_GERENCIAMENTOCHK.NRGERENCIAMENTOCHK = FCM_TAREFAGERCHK.NRGERENCIAMENTOCHK
                    WHERE FCM_GERENCIAMENTOCHK.NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function excluirFotoVistorias($parametros)
    {

        $sql = "DELETE FROM FCM_FOTOTAREFAGERCHK
                    WHERE NRFOTOTAREFAGERCHK = :NRFOTOTAREFAGERCHK";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function getAtividades($parametros)
    {

        $sql = "SELECT DISTINCT FCM_ATIVIDADECHK.NRATIVIDADECHK, FCM_ATIVIDADE.NMATIVIDADE
                  FROM FCM_ATIVIDADECHK
                  JOIN FCM_ATIVIDADE
                    ON FCM_ATIVIDADE.NRATIVIDADE = FCM_ATIVIDADECHK.NRATIVIDADE
                  JOIN FCM_TAREFACHK
                    ON FCM_TAREFACHK.NRATIVIDADECHK = FCM_ATIVIDADECHK.NRATIVIDADECHK
                    AND NRTAREFACHK IN (SELECT NRTAREFACHK
                                          FROM FCM_TAREFAGERCHK
                                         WHERE NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK)";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function getCodTarefaGerChk($parametros)
    {

        $sql = "SELECT NRTAREFAGERCHK
                    FROM FCM_TAREFAGERCHK
                    WHERE NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function anexarImagemVistorias($parametros)
    {

        $sql = "INSERT INTO FCM_FOTOTAREFAGERCHK (NRFOTOTAREFAGERCHK, NRTAREFAGERCHK, DSFOTOTAREFAGERCHK, IDATIVO, NRORG, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO, DSTYPE, NRSIZE)
        VALUES (:NRFOTOTAREFAGERCHK, :NRTAREFAGERCHK, :DSFOTOTAREFAGERCHK, 'S', :NRORG, SYSDATE, :CDOPERINCLUSAO, :NRORGINCLUSAO, :DSTYPE, :NRSIZE)";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function getCriterios($parametros)
    {

        $sql = "SELECT FCM_CRITERIOTARGERCHK.NRCRITERIOTARGERCHK, FCM_CRITERIOTARGERCHK.NMCRITERIOTARGERCHK, FCM_CRITERIOTARGERCHK.IDMARCADO
                    FROM FCM_CRITERIOTARGERCHK
                    JOIN FCM_TAREFAGERCHK
                    ON FCM_CRITERIOTARGERCHK.NRTAREFAGERCHK = FCM_TAREFAGERCHK.NRTAREFAGERCHK
                    JOIN FCM_TAREFACHK
                    ON FCM_TAREFAGERCHK.NRTAREFACHK = FCM_TAREFACHK.NRTAREFACHK
                    JOIN FCM_TAREFA 
                    ON FCM_TAREFA.NRTAREFA = FCM_TAREFACHK.NRTAREFA
                WHERE FCM_TAREFACHK.NRATIVIDADECHK = :NRATIVIDADECHK
                    AND FCM_TAREFAGERCHK.NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function updateCriterios($parametros, $paramQuery)
    {

        $sql = "UPDATE FCM_CRITERIOTARGERCHK
                    SET IDMARCADO = :IDMARCADO,
                        DTULTATU = SYSDATE,
                        CDOPERULTATU = :CDOPERULTATU,
                        NRORGULTATU = :NRORGULTATU
                  WHERE NRCRITERIOTARGERCHK IN (SELECT NRCRITERIOTARGERCHK
                                                    FROM FCM_CRITERIOTARGERCHK
                                                   WHERE NRTAREFAGERCHK IN (SELECT FCM_TAREFAGERCHK.NRTAREFAGERCHK
                                                    FROM FCM_TAREFAGERCHK
                                                    JOIN FCM_TAREFACHK
                                                      ON FCM_TAREFACHK.NRTAREFACHK = FCM_TAREFAGERCHK.NRTAREFACHK
                                                   WHERE FCM_TAREFAGERCHK.NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK
                                                     AND FCM_TAREFACHK.NRATIVIDADECHK = :NRATIVIDADECHK))" . $paramQuery;

        $this->connection->executeStatement($sql, $parametros);
    }

    public function updateObservacao($parametros)
    {

        $sql = "UPDATE FCM_TAREFAGERCHK
                SET DSOBSTAREFAGERCHK = :DSOBSTAREFAGERCHK,
                    DTULTATU = SYSDATE,
                    CDOPERULTATU = :CDOPERULTATU,
                    NRORGULTATU = :NRORGULTATU
                    WHERE NRTAREFAGERCHK IN (SELECT FCM_TAREFAGERCHK.NRTAREFAGERCHK
                                  FROM FCM_TAREFAGERCHK
                                  JOIN FCM_TAREFACHK
                                    ON FCM_TAREFACHK.NRTAREFACHK = FCM_TAREFAGERCHK.NRTAREFACHK
                                 WHERE FCM_TAREFAGERCHK.NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK
                                   AND FCM_TAREFACHK.NRATIVIDADECHK = :NRATIVIDADECHK)";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function updateStatusVistoria($parametros)
    {

        $sql = "UPDATE FCM_GERENCIAMENTOCHK
                SET IDSITUACAOGERCHK = :IDSITUACAOGERCHK,
                    DTULTATU = SYSDATE,
                    CDOPERULTATU = :CDOPERULTATU,
                    NRORGULTATU = :NRORGULTATU
                  WHERE NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK";


        $this->connection->executeStatement($sql, $parametros);
    }

    public function getNomeVistoria($parametros)
    {
        $sql = "SELECT NMGERENCIAMENTOCHK
                FROM FCM_GERENCIAMENTOCHK
                WHERE NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function atualizaHistoricoVistoria($parametros)
    {
        $sql = "INSERT INTO FCM_GERCHKHISTORICO (
                    NRGERCHKHISTORICO,      NRGERENCIAMENTOCHK, NMGERENCIAMENTOCHK, DSGERENCIAMENTOCHK,
                    DTHISTGERENCIAMENTOCHK, IDTIPOHISTORICO,    IDATIVO,            NRORG,
                    DTINCLUSAO,             CDOPERINCLUSAO,     NRORGINCLUSAO,      DTULTATU,
                    CDOPERULTATU,           NRORGULTATU
                )
                VALUES (
                    :NRGERCHKHISTORICO,     :NRGERENCIAMENTOCHK, :NMGERENCIAMENTOCHK, :DSGERENCIAMENTOCHK,
                    SYSDATE,                :IDTIPOHISTORICO,    'S',                 :NRORG,
                    SYSDATE,                :CDOPERINCLUSAO,     :NRORGINCLUSAO,      SYSDATE,
                    :CDOPERULTATU,          :NRORGULTATU
                )";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function getTarefaVinculada($parametros)
    {
        $sql = "SELECT CHK.NRCHECKLISTAGEND, CHK.NMCHECKLISTAGEND
                FROM FCM_CHECKLISTAGEND CHK
                JOIN FCM_GERENCIAMENTOCHK GER ON CHK.NRCHECKLISTAGEND = GER.NRCHECKLISTAGEND
                WHERE GER.NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function atualizaHistoricoTarefa($parametros)
    {
        $sql = "INSERT INTO FCM_CHKAGENDHISTORICO (
                    NRCHKAGENDHISTORICO,    NRCHECKLISTAGEND,   NMCHECKLISTAGEND,   DSCHKAGENDHISTORICO,
                    DTCHKAGENDHISTORICO,    IDTIPOHISTORICO,    IDATIVO,            NRORG,
                    DTINCLUSAO,             CDOPERINCLUSAO,     NRORGINCLUSAO,      DTULTATU,
                    CDOPERULTATU,           NRORGULTATU
                )
                VALUES (
                    :NRCHKAGENDHISTORICO,   :NRCHECKLISTAGEND,  :NMCHECKLISTAGEND,  :DSCHKAGENDHISTORICO,
                    SYSDATE,                :IDTIPOHISTORICO,   'S',                :NRORG,
                    SYSDATE,                :CDOPERINCLUSAO,    :NRORGINCLUSAO,     SYSDATE,
                    :CDOPERULTATU,          :NRORGULTATU
                )";

        $this->connection->executeStatement($sql, $parametros);
    }
}
