<?php

namespace FM\Factory;

use Doctrine\ORM\EntityManager;
use FM\Traits\TQuery;

class SolicitacaoFactory
{

    use TQuery;

    protected $entityManager;
    protected $connection;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getLocalRequest($params)
    {
        $sql = "SELECT FCM_LOCALCLI.NRLOCALCLIENTE, FCM_LOCALCLI.NMLOCALCLIENTE,
                           FCM_LOCALCLI.NRSETOR, FCM_LOCALCLI.NRLOCALCLIENTEPAI
                     FROM FCM_LOCALCLI
                     JOIN FCM_TIPOLOCALCLI
                       ON FCM_LOCALCLI.NRTIPOLOCALCLI = FCM_TIPOLOCALCLI.NRTIPOLOCALCLI
                    WHERE FCM_TIPOLOCALCLI.IDTIPOLOCALCLI = " . $params["parent"];

        return $this->connection->executeQuery($sql)->fetchAllAssociative();
    }

    public function insertNewRequest($parametros)
    {

        $sql = "INSERT INTO FCM_SOLICITACAO (NRSOLICITACAO, NMSOLICITACAO, DTSOLICITACAO, IDSITUACAO, NRLOCALCLIENTE,
            CDOPERABERTURA, DSSOLICITACAO, NRORG, IDATIVO, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO, NRORGULTATU, CDOPERULTATU, DTULTATU)
              VALUES (:NRSOLICITACAO, :NMSOLICITACAO, SYSDATE, :IDSITUACAO, :NRLOCALCLIENTE, :CDOPERABERTURA,
                      :DSSOLICITACAO, :NRORG, 'S', SYSDATE, :CDOPERINCLUSAO, :NRORGINCLUSAO, :NRORGULTATU, :CDOPERULTATU, SYSDATE)";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function insertRequestHistory($parametros)
    {
       
        $sql = "INSERT INTO FCM_SOLICITACAOHISTORICO (NRSOLICITACAOHISTORICO, NRSOLICITACAO, NMSOLICITACAO, DTHISTSOLICITACAO,
                IDSITUACAO, IDTIPOHISTORICO, CDOPERSOLICITANTE, DSSOLICITACAO, IDSATISFACAOSOLICITA, NRORG, IDATIVO, CDOPERULTATU, DTULTATU)
                VALUES (:NRSOLICITACAOHISTORICO, :NRSOLICITACAO, :NMSOLICITACAO, SYSDATE, :IDSITUACAO, :IDTIPOHISTORICO,
              :CDOPERSOLICITANTE, :DSSOLICITACAO, :IDSATISFACAOSOLICITA, :NRORG, 'S', :CDOPERULTATU, SYSDATE)";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function getSituationRequest()
    {

        $sql = "SELECT DISTINCT S.IDSITUACAO AS NRIDSITUACAO,
                  CASE S.IDSITUACAO WHEN '1' THEN 'Pendente'
                     WHEN '2' THEN 'Em andamento'
                     WHEN '3' THEN 'Aguardando Avaliação'
                     WHEN '4' THEN 'Concluído'
                     ELSE NULL END AS IDSITUACAO
                     FROM FCM_SOLICITACAO S";

        return $this->connection->executeQuery($sql)->fetchAllAssociative();
    }

    public function getNameRequest()
    {

        $sql = "SELECT S.NMSOLICITACAO, S.NRSOLICITACAO
                  FROM FCM_SOLICITACAO S";

        return $this->connection->executeQuery($sql)->fetchAllAssociative();
    }

    public function getSolicitacoes($userId, $filter)
    {

        $sql = "SELECT S.NRSOLICITACAO, S.NMSOLICITACAO,  S.DSSOLICITACAO, S.NRLOCALCLIENTE, LC.NMLOCALCLIENTE, S.DTSOLICITACAO,
                       TO_CHAR(S.DTSOLICITACAO, 'DD/MM') DTAGEND, TO_CHAR(S.DTSOLICITACAO, 'HH24:MI') HORAAGEND, LC.NRLOCALCLIENTEPAI AS LOCALPAI, LCP.NMLOCALCLIENTE AS NMLOCALPAI,
                  CASE S.IDSITUACAO
                    WHEN '1' THEN 'Pendente'
                    WHEN '2' THEN  'Em andamento'
                    WHEN '3' THEN 'Aguardando Avaliação'
                    WHEN '4' THEN 'Concluído'
                    ELSE NULL END AS IDSITUACAO
                 FROM FCM_SOLICITACAO S
                 JOIN FCM_LOCALCLI LC
                   ON LC.NRLOCALCLIENTE = S.NRLOCALCLIENTE
                 JOIN FCM_LOCALCLI LCP
                  ON LCP.NRLOCALCLIENTE = LC.NRLOCALCLIENTEPAI
                WHERE S.CDOPERABERTURA IN ({$userId})" . $filter . "
                ORDER BY S.DTSOLICITACAO";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function showRequest($parametros)
    {

        $sql = "SELECT S.NRSOLICITACAO, S.NMSOLICITACAO, S.DSSOLICITACAO, TO_CHAR(S.DTSOLICITACAO, 'DD/MM HH24:MI') DTSOLICITACAO, S.NRLOCALCLIENTE, S.IDSITUACAO, LC.NMLOCALCLIENTE,
                    CASE S.IDSITUACAO
                    WHEN '1' THEN 'Pendente'
                    WHEN '2' THEN  'Em andamento'
                    WHEN '3' THEN 'Aguardando Avaliação'
                    WHEN '4' THEN 'Concluído'
                    ELSE NULL END AS IDSITUACAO
                FROM FCM_SOLICITACAO S
                JOIN FCM_LOCALCLI LC
                ON LC.NRLOCALCLIENTE = S.NRLOCALCLIENTE
                WHERE S.NRSOLICITACAO = :NRSOLICITACAO";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function upRequest($parametros)
    {

        $sql = "UPDATE FCM_SOLICITACAO
                  SET IDSITUACAO = :IDSITUACAO,
                      DSSOLICITACAO = :DSSOLICITACAO
                WHERE NRSOLICITACAO = :NRSOLICITACAO";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function insertImg($param)
    {

        $sql = "INSERT INTO FCM_IMGSOLICITACAO (NRIMGSOLICITACAO, NRSOLICITACAO, DSCAMINHO, NRORG, IDATIVO, DSTYPE, NRSIZE, CDOPERINCLUSAO, DTINCLUSAO)
              VALUES (:NRIMGSOLICITACAO, :NRSOLICITACAO, :DSCAMINHO, :NRORG, 'S', :DSTYPE, :NRSIZE, :CDOPERINCLUSAO, SYSDATE)";

        $this->connection->executeStatement($sql, $param);
    }

    public function getFotosSolicitacao($param)
    {

        $sql = "SELECT NRIMGSOLICITACAO, DSCAMINHO
                  FROM FCM_IMGSOLICITACAO
                 WHERE NRSOLICITACAO = " . $param['NRSOLICITACAO'];

        return $this->connection->executeQuery($sql)->fetchAllAssociative();
    }

    public function getAvaliacao($parametros)
    {
        $sql = "SELECT IDSATISFACAOSOLICITA FROM FCM_SOLICITACAOHISTORICO WHERE NRSOLICITACAO = :NRSOLICITACAO AND IDSATISFACAOSOLICITA IS NOT NULL";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function getTarefasVinculadas($parametros)
    {
        $sql = "SELECT FCM_SOLICITACAOTAREFAS.NRCHECKLISTAGEND
                    FROM FCM_SOLICITACAOTAREFAS
                    JOIN FCM_CHECKLISTAGEND
                    ON FCM_CHECKLISTAGEND.NRCHECKLISTAGEND = FCM_SOLICITACAOTAREFAS.NRCHECKLISTAGEND
                    WHERE NRSOLICITACAO = :NRSOLICITACAO";
        
        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function setStatusTarefas($parametros)
    {
        $sql = "UPDATE FCM_CHECKLISTAGEND
                SET IDSITUACAOAGEND = :IDSITUACAOAGEND,
                    CDOPERULTATU = :CDOPERULTATU,
                    DTULTATU = SYSDATE
                WHERE NRCHECKLISTAGEND = :NRCHECKLISTAGEND";

        $this->connection->executeStatement($sql, $parametros);
    }
}
