/* Sistemas Integrados TECNISA
   Compras e Suprimentos

Nome: 8986_CMPSTPS_EXCLUIR_PARTFILI

Descrio:
Excluso Automtica de Particularidades

P_TPRODUTO    - Todos os produtos
P_CDPRODINI   - Produto inicial
P_CDPRODFIN   - Produto final
P_CDFILIAL    - Filiais
P_CDMARCA     - Marcas
P_CDFORNECED  - Fornecedores
P_CDTIPPART   - Particularidades
P_CDGRUPFILI  - Grupo de filiais
*/

IF EXISTS (SELECT * FROM sysobjects O, sysusers U
          WHERE
            o.name = 'EXCLUIR_PARTFILI'  and
            type = 'P'                  and
            u.uid = o.uid               and
            u.name = USER)
   DROP PROCEDURE EXCLUIR_PARTFILI;
GO

CREATE PROCEDURE EXCLUIR_PARTFILI
   @P_TPRODUTO    VARCHAR(1),
   @P_CDPRODINI   VARCHAR(20),
   @P_CDPRODFIN   VARCHAR(20),
   @P_CDFILIAL    VARCHAR(255),
   @P_CDMARCA     VARCHAR(255),
   @P_CDFORNECED  VARCHAR(255),
   @P_CDTIPPART   VARCHAR(255),
   @P_CDGRUPFILI  VARCHAR(10),
   @P_CDOPERADOR  VARCHAR(12),
   @P_CDFILIALORIG VARCHAR(4) = NULL,
   @P_COMMIT VARCHAR(1)
AS
DECLARE   @V_EMITENTE    VARCHAR(4);
DECLARE   @V_TFILIAL     VARCHAR(1);
DECLARE   @V_TCDMARCA    VARCHAR(1);
DECLARE   @V_TCDFORNECED VARCHAR(1);
DECLARE   @V_TCDFILIALORIG VARCHAR(1);
DECLARE   @V_PARTFILI_CDFILIAL  VARCHAR(4);
DECLARE   @V_PARTFILI_CDPRODUTO VARCHAR(10);
DECLARE   @V_PARTFILI_CDTIPPART VARCHAR(1);
DECLARE   @V_PARTFILI_NRSEQPART VARCHAR(10);
DECLARE   @V_CDPRODFIN   VARCHAR(30);

BEGIN
   SET @V_CDPRODFIN = @P_CDPRODFIN + 'ZZZZZZZZZZ';
   IF @P_CDFILIAL IS NULL BEGIN
      SET @V_TFILIAL = 'T';
   END;
   IF @P_CDMARCA IS NULL BEGIN
      SET @V_TCDMARCA = 'T';
   END;
   IF @P_CDFORNECED IS NULL BEGIN
      SET @V_TCDFORNECED = 'T';
   END;
   IF @P_CDFILIALORIG IS NULL BEGIN
      SET @V_TCDFILIALORIG = 'T';
   END;
   DECLARE C_PARTFILI CURSOR FOR
      (SELECT
          PARTFILI.CDFILIAL,
          PARTFILI.CDPRODUTO,
          PARTFILI.CDTIPPART,
          PARTFILI.NRSEQPART
       FROM
          PARTFILI
       WHERE (@P_CDGRUPFILI IS NULL OR
              EXISTS(SELECT 1
                     FROM FILGRUPFILI
                     WHERE FILGRUPFILI.CDFILIAL   = PARTFILI.CDFILIAL
                       AND FILGRUPFILI.CDGRUPFILI = @P_CDGRUPFILI)
              )
         AND ((CHARINDEX(PARTFILI.CDMARCA, @P_CDMARCA) > 0) OR @V_TCDMARCA = 'T')
         AND ((CHARINDEX(PARTFILI.CDFORNECED, @P_CDFORNECED) > 0) OR @V_TCDFORNECED = 'T')
         AND ((CHARINDEX(PARTFILI.CDFILIAL, @P_CDFILIAL) > 0) OR @V_TFILIAL = 'T')
         AND ((CHARINDEX(PARTFILI.CDTIPPART, @P_CDTIPPART) > 0))
         AND PARTFILI.CDFILCOTA IS NULL
         AND PARTFILI.NRCOLEPRECO IS NULL
         AND ((PARTFILI.CDFILIAL <> @P_CDFILIALORIG) OR (@V_TCDFILIALORIG = 'T'))
         AND EXISTS (SELECT 1
                       FROM FILIOPER
                      WHERE FILIOPER.CDFILIAL = PARTFILI.CDFILIAL
                        AND FILIOPER.CDOPERADOR = @P_CDOPERADOR)
         AND (@P_TPRODUTO = 'T' OR
              EXISTS(SELECT 1
                     FROM PRODUTO
                     WHERE PRODUTO.CDPRODUTO = PARTFILI.CDPRODUTO
                       AND PRODUTO.CDARVPROD BETWEEN @P_CDPRODINI AND @V_CDPRODFIN)
              )
         AND NOT EXISTS (SELECT 1
                           FROM PARAMPRODSUP, FILIAL, FORNECEDOR, PARASUPRI
                          WHERE PARAMPRODSUP.CDPRODUTO = PARTFILI.CDPRODUTO
                            AND PARAMPRODSUP.CDFILIAL = PARTFILI.CDFILIAL
                            AND PARAMPRODSUP.CDFILIOPELOG = FILIAL.CDFILIAL
                            AND FILIAL.CDFORNOPELOG = FORNECEDOR.CDFORNECED
                            AND PARASUPRI.CDFILIAL = ISNULL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL)
                            AND PARASUPRI.IDUTILCONSSOLIOL = 'N'
                            AND PARTFILI.CDTIPPART = '4'))
   OPEN C_PARTFILI;
   FETCH NEXT FROM C_PARTFILI INTO @V_PARTFILI_CDFILIAL,
                                   @V_PARTFILI_CDPRODUTO,
                                   @V_PARTFILI_CDTIPPART,
                                   @V_PARTFILI_NRSEQPART;
   WHILE (@@FETCH_STATUS = 0)
   BEGIN
      DELETE
      FROM PARTFILI
      WHERE @V_PARTFILI_CDFILIAL  = PARTFILI.CDFILIAL
        AND @V_PARTFILI_CDPRODUTO = PARTFILI.CDPRODUTO
        AND @V_PARTFILI_CDTIPPART = PARTFILI.CDTIPPART
        AND @V_PARTFILI_NRSEQPART = PARTFILI.NRSEQPART;
      FETCH NEXT FROM C_PARTFILI INTO @V_PARTFILI_CDFILIAL,
                                      @V_PARTFILI_CDPRODUTO,
                                      @V_PARTFILI_CDTIPPART,
                                      @V_PARTFILI_NRSEQPART;
   END;
   CLOSE C_PARTFILI;
   DEALLOCATE C_PARTFILI;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'EXCLUIR_PARTFILI','6.25.XXX';
GO

