import { clearStorage, makeServer, reload } from '@zeedhi/zeedhi-miragejs';
import { Interceptor } from '@zeedhi/core';
import adapter from '@zeedhi/axios-mirage-adapter';
import { HttpCRUDTranslator } from '@/http-crud-translator/http-crud-translator';
import { useMirage } from './use-mirage';
import { RequestLog, registerLogger } from './request-logger';
import config from './config';

Interceptor.addRequestSuccess((axiosConfig) => ({ ...axiosConfig, adapter }));

const endpoint = process.env.VUE_APP_MIRAGE_END_POINT;
makeServer({ endpoint, config, logging: true });

if (!navigator.onLine) {
    useMirage();
}

registerLogger();

window.addEventListener('online', async () => {
    useMirage(false);

    const item = localStorage.getItem('fmapp-log') || '[]';
    const logs = JSON.parse(item);

    console.warn(logs);

    logs.forEach(({ method, row }: RequestLog) => {
        if (method === 'post') {
            HttpCRUDTranslator.post(`/${row.uri.split('/')[3]}`, row);
        }

        // const { id } = row;
        // if (method === 'put') {
        //     Http.put(`/rota/${id}`, row);
        // }

        // if (method === 'delete') {
        //     Http.delete(`/rota/${id}`);
        // }
      });

      // limpa o histórico
      localStorage.removeItem('fmapp-log');

      await clearStorage();

      await reload();
});

window.addEventListener('offline', async () => {
    useMirage();
});
